@@ -11,9 +11,8 @@ class Command(UpdateTwitterCommand):
 
     help = "Fetches the latest data about each Twitter Tweet"
 
-    singular_noun = 'Tweet'
-    plural_noun = 'Tweets'
+    singular_noun = "Tweet"
+    plural_noun = "Tweets"
 
     def fetch(self, screen_name):
         return TweetsFetcher(screen_name=screen_name).fetch()
-
